import React, {Component} from 'react'
import PropTypes from 'prop-types'
import { Form, Row, Col, Input, InputNumber, Select, Radio, Tooltip } from 'antd'
import { QuestionCircleOutlined } from '@ant-design/icons'

import { formRule } from '@/utils/option.js'
import TransferForm from '@/templates/zshare/transferform'
// import './index.scss'

class MainSearch extends Component {
  static propTpyes = {
    columns: PropTypes.array,
    card: PropTypes.any,
    inputSubmit: PropTypes.any   // 回车提交事件
  }

  componentDidMount () {
    try {
      let _form = document.getElementById('label')
      if (_form && _form.select) {
        _form.select()
      }
    } catch (e) {
      console.warn('表单focus失败！')
    }
  }

  handleConfirm = () => {
    // 表单提交时检查输入值是否正确
    return new Promise((resolve, reject) => {
      this.props.form.validateFieldsAndScroll((err, values) => {
        if (!err) {
          let targetKeys = this.refs['column-transfer'].state.targetKeys

          delete values.type // 删除type，此处值为'合并列'文字

          let subfield = []  // 用于查看合并列字段
          this.props.columns.forEach(col => {
            if (col.field && targetKeys.includes(col.uuid)) {
              subfield.push(col.field)
            }
          })
          subfield = subfield.join(', ')

          let _card = {...this.props.card, ...values, sublist: targetKeys, subfield: subfield}

          delete _card.focus

          resolve(_card)
        } else {
          reject(err)
        }
      })
    })
  }

  handleSubmit = (e) => {
    e.preventDefault()

    if (this.props.inputSubmit) {
      this.props.inputSubmit()
    }
  }

  render() {
    const { card } = this.props
    const { getFieldDecorator } = this.props.form
    const formItemLayout = {
      labelCol: {
        xs: { span: 24 },
        sm: { span: 6 }
      },
      wrapperCol: {
        xs: { span: 24 },
        sm: { span: 18 }
      }
    }
    return (
      <Form {...formItemLayout} style={{minHeight: '190px'}} id="columncolspan">
        <Row gutter={24}>
          <Col span={12}>
            <Form.Item label="名称">
              {getFieldDecorator('label', {
                initialValue: card.label,
                rules: [
                  {
                    required: true,
                    message: '请输入名称!'
                  },
                  {
                    max: formRule.input.max,
                    message: formRule.input.message
                  }
                ]
              })(<Input placeholder="" autoComplete="off" onPressEnter={this.handleSubmit} />)}
            </Form.Item>
          </Col>
          <Col span={12}>
            <Form.Item label="类型">
              {getFieldDecorator('type', {
                initialValue: '合并列'
              })(<Input placeholder="" autoComplete="off" disabled={true}/>)}
            </Form.Item>
          </Col>
          <Col span={12}>
            <Form.Item label="对齐方式">
              {getFieldDecorator('Align', {
                initialValue: card.Align,
                rules: [
                  {
                    required: true,
                    message: '请选择对齐方式!'
                  }
                ]
              })(
                <Select
                  getPopupContainer={() => document.getElementById('columncolspan')}
                >
                  <Select.Option value="left">左对齐</Select.Option>
                  <Select.Option value="right">右对齐</Select.Option>
                  <Select.Option value="center">居中</Select.Option>
                </Select>
              )}
            </Form.Item>
          </Col>
          <Col span={12}>
            <Form.Item label="列宽">
              {getFieldDecorator('Width', {
                initialValue: card.Width,
                rules: [
                  {
                    required: true,
                    message: '请输入列宽!'
                  }
                ]
              })(<InputNumber min={1} max={1000} precision={0} onPressEnter={this.handleSubmit} />)}
            </Form.Item>
          </Col>
          <Col span={12}>
            <Form.Item label={
              <Tooltip placement="topLeft" title="选择显示分组，表格会展开添加分组的子列，此时排列方式会失效。">
                <QuestionCircleOutlined className="mk-form-tip" />
                显示分组
              </Tooltip>
            }>
              {getFieldDecorator('unfold', {
                initialValue: card.unfold || 'false'
              })(
                <Radio.Group>
                  <Radio value="true">是</Radio>
                  <Radio value="false">否</Radio>
                </Radio.Group>
              )}
            </Form.Item>
          </Col>
          <Col span={12}>
            <Form.Item label="隐藏">
              {getFieldDecorator('Hide', {
                initialValue: card.Hide || 'false'
              })(
                <Radio.Group>
                  <Radio value="true">是</Radio>
                  <Radio value="false">否</Radio>
                </Radio.Group>
              )}
            </Form.Item>
          </Col>
          <Col span={12}>
            <Form.Item label="排列">
              {getFieldDecorator('order', {
                initialValue: card.order,
                rules: [
                  {
                    required: true,
                    message: '请选择排列方式!'
                  }
                ]
              })(
                <Select getPopupContainer={() => document.getElementById('columncolspan')} >
                  <Select.Option value="vertical">纵向</Select.Option>
                  <Select.Option value="horizontal">横向</Select.Option>
                  <Select.Option value="vertical2">纵向(2列)</Select.Option>
                  <Select.Option value="topPicBottomText">上图下文</Select.Option>
                  <Select.Option value="leftPicRightText">左图右文</Select.Option>
                </Select>
              )}
            </Form.Item>
          </Col>
          <Col span={24}>
            <TransferForm columns={this.props.columns} ref="column-transfer" selected={card.sublist}/>
          </Col>
        </Row>
      </Form>
    )
  }
}

export default Form.create()(MainSearch)